<?php

namespace Litecms\Series\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Series\Models\Series;

class SeriesPolicy
{

    /**
     * Determine if the given user can view the series.
     *
     * @param UserPolicyInterface $authUser
     * @param Series $series
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, Series $series)
    {
        if ($authUser->canDo('series.series.view') && $authUser->isAdmin()) {
            return true;
        }

        return $series->user_id == user_id() && $series->user_type == user_type();
    }

    /**
     * Determine if the given user can create a series.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('series.series.create');
    }

    /**
     * Determine if the given user can update the given series.
     *
     * @param UserPolicyInterface $authUser
     * @param Series $series
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, Series $series)
    {
        if ($authUser->canDo('series.series.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $series->user_id == user_id() && $series->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given series.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, Series $series)
    {
        return $series->user_id == user_id() && $series->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given series.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, Series $series)
    {
        if ($authUser->canDo('series.series.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given series.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, Series $series)
    {
        if ($authUser->canDo('series.series.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
